# Generated by Django 3.2.8 on 2021-10-05 13:02

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('django_hub_sdk', '0001_initial'),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.AddField(
            model_name='hubuser',
            name='user',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='tokens', to=settings.AUTH_USER_MODEL, verbose_name='Users'),
        ),
    ]



# Generated by Django 3.2.8 on 2021-10-05 13:08

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_hub_sdk', '0003_auto_20211005_1304'),
    ]

    operations = [
        migrations.RenameField(
            model_name='usercompany',
            old_name='hub_uuid',
            new_name='uuid',
        ),
    ]



# Generated by Django 3.2.8 on 2021-10-07 14:05

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ('django_hub_sdk', '0006_huboauthtoken_uuid'),
    ]

    operations = [
        migrations.AlterField(
            model_name='hubuser',
            name='token',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='user', to='django_hub_sdk.huboauthtoken', verbose_name='Tokens'),
        ),
        migrations.AlterField(
            model_name='hubuser',
            name='user',
            field=models.ForeignKey(null=True, on_delete=django.db.models.deletion.CASCADE, related_name='tokens', to=settings.AUTH_USER_MODEL, verbose_name='Users'),
        ),
    ]



# Generated by Django 3.2.8 on 2021-10-05 18:16

from django.db import migrations, models
import uuid


class Migration(migrations.Migration):

    dependencies = [
        ('django_hub_sdk', '0005_auto_20211005_1815'),
    ]

    operations = [
        migrations.AddField(
            model_name='huboauthtoken',
            name='uuid',
            field=models.UUIDField(default=uuid.uuid4, editable=False, verbose_name='User UUID'),
        ),
    ]



# Generated by Django 3.2.8 on 2021-10-05 18:15

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_hub_sdk', '0004_rename_hub_uuid_usercompany_uuid'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='hubuser',
            options={'verbose_name': 'Hub User', 'verbose_name_plural': 'Hub Users'},
        ),
        migrations.AlterField(
            model_name='huboauthtoken',
            name='access_token',
            field=models.TextField(blank=True, null=True, verbose_name='Access Token'),
        ),
        migrations.AlterField(
            model_name='huboauthtoken',
            name='refresh_token',
            field=models.TextField(blank=True, null=True, verbose_name='Refresh Token'),
        ),
    ]



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['django_hub_sdk', 'django_hub_sdk.migrations']

package_data = \
{'': ['*']}

install_requires = \
['django>=3.0,<4.0', 'djangorestframework', 'requests2']

setup_kwargs = {
    'name': 'django-hub-sdk',
    'version': '0.1.0',
    'description': 'The ISS (International Space Station) aims to be a space station (client) of connection between the microservices of its ecosystem and the authentication and permissions microservice of the user that here is called in the script as Hub.permissions modules / microservices (Hub)',
    'long_description': '# django-hub-sdk\n\nThe ISS (International Space Station) aims to be a space station (client) of connection between the microservices of its\necosystem and the authentication and permissions microservice of the user that here is called in the script as\nHub.permissions modules / microservices (Hub)',
    'author': 'Guilherme Haynes Howe',
    'author_email': 'zerossb@gmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/bildvitta/django-hub-sdk',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)



# Generated by Django 3.2.8 on 2021-10-05 13:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_hub_sdk', '0002_hubuser_user'),
    ]

    operations = [
        migrations.AlterField(
            model_name='huboauthtoken',
            name='access_token',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Access Token'),
        ),
        migrations.AlterField(
            model_name='huboauthtoken',
            name='expires_in',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Expires In'),
        ),
        migrations.AlterField(
            model_name='huboauthtoken',
            name='expires_in_dt',
            field=models.DateTimeField(blank=True, max_length=255, null=True, verbose_name='Expires In DT'),
        ),
        migrations.AlterField(
            model_name='huboauthtoken',
            name='refresh_token',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Refresh Token'),
        ),
        migrations.AlterField(
            model_name='usercompany',
            name='hub_uuid',
            field=models.UUIDField(blank=True, null=True, verbose_name='Hub Company UUID'),
        ),
        migrations.AlterField(
            model_name='usercompany',
            name='name',
            field=models.CharField(blank=True, max_length=255, null=True, verbose_name='Hub Company Name'),
        ),
    ]
